'use strict';

var fs = require('fs');
var promises = require('fs/promises');
var micromatch = require('micromatch');
var path = require('path');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var micromatch__default = /*#__PURE__*/_interopDefault(micromatch);
var path__default = /*#__PURE__*/_interopDefault(path);

function createPatternMatcher(patterns) {
  if (!patterns || Array.isArray(patterns) && patterns.length === 0 || patterns === "") {
    return () => true;
  }
  return (fileName) => isMatch(fileName, patterns);
}
function isMatch(fileName, pattern, options) {
  const absoluteFilePath = path__default.default.resolve(fileName);
  const normalizedFilePath = path__default.default.relative(process.cwd(), absoluteFilePath).replace(/\\/g, "/");
  const baseOptions = { dot: true, bash: true, basename: true, ...options };
  if (Array.isArray(pattern)) {
    const positivePatterns = pattern.filter((p) => !p.startsWith("!"));
    const negativePatterns = pattern.filter((p) => p.startsWith("!")).map((p) => p.slice(1));
    const positiveMatch = positivePatterns.length === 0 || micromatch__default.default.isMatch(normalizedFilePath, positivePatterns, baseOptions);
    const negativeMatch = negativePatterns.length > 0 && micromatch__default.default.isMatch(normalizedFilePath, negativePatterns, baseOptions);
    return positiveMatch && !negativeMatch;
  }
  return micromatch__default.default.isMatch(normalizedFilePath, pattern, baseOptions);
}
async function waitForFile(filePath, timeout = 5e3) {
  const start = Date.now();
  while (Date.now() - start < timeout)
    if (fs.existsSync(filePath)) {
      try {
        await promises.readFile(filePath, "utf-8");
        return;
      } catch {
        await new Promise((resolve2) => setTimeout(resolve2, 100));
      }
    }
  throw new Error(`File not available after ${timeout}ms: ${filePath}`);
}
function normalizePath(p, shouldResolve = false) {
  const resolved = shouldResolve && fs.existsSync(p) ? fs.realpathSync(path__default.default.resolve(p)) : p;
  return resolved.replace(/\\/g, "/");
}
function normalizeAndResolvePath(p) {
  return normalizePath(path.resolve(p), true);
}
const np = normalizePath;
function isPathEqual(path1, path2) {
  return path.resolve(normalizePath(path1)) === path.resolve(normalizePath(path2));
}

exports.createPatternMatcher = createPatternMatcher;
exports.isMatch = isMatch;
exports.isPathEqual = isPathEqual;
exports.normalizeAndResolvePath = normalizeAndResolvePath;
exports.normalizePath = normalizePath;
exports.np = np;
exports.waitForFile = waitForFile;
//# sourceMappingURL=utils.js.map
//# sourceMappingURL=utils.js.map