/**
 * Pattern types that can be used for file filtering
 */
export type FilterPattern = string | RegExp | ((fileName: string) => boolean);

/**
 * File filter configuration options
 */
export interface FileFilterOptions {
  /**
   * Patterns to include files
   * Can be string (exact match or extension), RegExp, or function
   */
  include?: FilterPattern | FilterPattern[];

  /**
   * Patterns to exclude files
   * Can be string (exact match or extension), RegExp, or function
   * Takes precedence over include patterns
   */
  exclude?: FilterPattern | FilterPattern[];
}

/**
 * Deployment target configuration
 */
export interface DeployTarget {
  /**
   * Path to deploy files to
   */
  path: string;

  /**
   * Type of deployment target
   */
  type: 'icloud' | 'local';

  /**
   * Additional metadata about the target
   */
  metadata?: Record<string, unknown>;
}
